#ifndef _DJPLAY_H_INCLUDED
#define _DJPLAY_H_INCLUDED

#define _(x) gettext(x)

#include <libintl.h>
#include <qdialog.h>

#ifdef __WIN__
#include <winsock.h>
#endif

#ifdef QT_DLL
#define setCaption(x) setCaption((QString)x+" (Qt)")
#endif

class MainWnd;
class QApplication;
class Playlist;
class Frame;
class Mixer;
class Config;
class LinePanel;
class PflPanel;

extern QApplication *app;
extern Playlist *playlist;
extern Frame *frame;
extern QWidget *mainmix;
extern Mixer *mixer;
extern int video_on;
extern char video_display[128];
extern char out_pipe[2048];
extern int out_relaunch;
extern Config *config;
extern int talk_level;
extern LinePanel *line1, *line2;
extern PflPanel *pfl;

#endif
